pub struct TaskAccount {
pub avs: Pubkey,
pub task_id: u64,
pub submission_deadline: u64,
pub verification_threshold_bps: u64,
pub created_slot: u64,
pub total_submissions: u32,
pub verified_submissions: u32,
pub active: bool,
pub bump: u8,
}Fields
avs: Pubkeytask_id: u64submission_deadline: u64verification_threshold_bps: u64created_slot: u64total_submissions: u32verified_submissions: u32active: boolbump: u8Trait Implementations
Sourceimpl AccountDeserialize for TaskAccount
impl AccountDeserialize for TaskAccount
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for TaskAccount
impl AccountSerialize for TaskAccount
Sourceimpl BorshDeserialize for TaskAccountwhere
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
u32: BorshDeserialize,
bool: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for TaskAccountwhere
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
u32: BorshDeserialize,
bool: BorshDeserialize,
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TaskAccountwhere
Pubkey: BorshSerialize,
u64: BorshSerialize,
u32: BorshSerialize,
bool: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for TaskAccountwhere
Pubkey: BorshSerialize,
u64: BorshSerialize,
u32: BorshSerialize,
bool: BorshSerialize,
u8: BorshSerialize,
Sourceimpl Clone for TaskAccount
impl Clone for TaskAccount
Sourcefn clone(&self) -> TaskAccount
fn clone(&self) -> TaskAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskAccount
impl Debug for TaskAccount
Sourceimpl Discriminator for TaskAccount
impl Discriminator for TaskAccount
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl IdlBuild for TaskAccount
impl IdlBuild for TaskAccount
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl Space for TaskAccount
impl Space for TaskAccount
const INIT_SPACE: usize = 74usize