pub struct TaskSubmission {
pub task: Pubkey,
pub operator: Pubkey,
pub submitted_price: i64,
pub confidence: u64,
pub publish_time: i64,
pub submitted_slot: u64,
pub verified: bool,
pub is_correct: bool,
pub actual_pyth_price: i64,
pub actual_pyth_conf: u64,
pub bump: u8,
}Fields
task: Pubkeyoperator: Pubkeysubmitted_price: i64confidence: u64publish_time: i64submitted_slot: u64verified: boolis_correct: boolactual_pyth_price: i64actual_pyth_conf: u64bump: u8Trait Implementations
Sourceimpl AccountDeserialize for TaskSubmission
impl AccountDeserialize for TaskSubmission
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for TaskSubmission
impl AccountSerialize for TaskSubmission
Sourceimpl BorshDeserialize for TaskSubmissionwhere
Pubkey: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
bool: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for TaskSubmissionwhere
Pubkey: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
bool: BorshDeserialize,
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TaskSubmissionwhere
Pubkey: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
bool: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for TaskSubmissionwhere
Pubkey: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
bool: BorshSerialize,
u8: BorshSerialize,
Sourceimpl Clone for TaskSubmission
impl Clone for TaskSubmission
Sourcefn clone(&self) -> TaskSubmission
fn clone(&self) -> TaskSubmission
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskSubmission
impl Debug for TaskSubmission
Sourceimpl Discriminator for TaskSubmission
impl Discriminator for TaskSubmission
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl IdlBuild for TaskSubmission
impl IdlBuild for TaskSubmission
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl Space for TaskSubmission
impl Space for TaskSubmission
const INIT_SPACE: usize = 115usize